#
# spec file for package python3-decorator
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-decorator
Version:        4.0.2
Release:        6.2
Url:            http://pypi.python.org/pypi/decorator
Summary:        Better living through Python with decorators
License:        BSD-2-Clause
Group:          Development/Languages/Python
Source:         http://pypi.python.org/packages/source/d/decorator/decorator-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildArch:      noarch

%description
As of now, writing custom decorators correctly requires some experience and it
is not as easy as it could be. For instance, typical implementations of
decorators involve nested functions, and we all know that flat is better than
nested. Moreover, typical implementations of decorators do not preserve the
signature of decorated functions, thus confusing both documentation tools and
developers.

The aim of the decorator module it to simplify the usage of decorators for the
average programmer, and to popularize decorators usage giving examples of
useful decorators, such as memoize, tracing, redirecting_stdout, locked, etc.

%prep
%setup -q -n decorator-%{version}
sed -i 's/\r//' docs/README.rst # Fix EOL encoding

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}
rm -rf %{buildroot}%{python3_sitelib}/__pycache__/

%files
%defattr(-,root,root,-)
%doc docs/README.rst LICENSE.txt CHANGES.txt
%{python3_sitelib}/decorator.py*
%{python3_sitelib}/decorator-%{version}-py%{py3_ver}.egg-info

%changelog
* Mon Aug 10 2015 arun@gmx.de
- specfile:
  * removed 2to3 dependency
  * updated location of README.rst
  * added LICENSE.txt and CHANGES.txt
- update to version 4.0.2:
  * Fix: docs/README.rst was not included in MANIFEST.in by accident,
    thus breaking the source installation (2015/07/28)
- changes from version 4.0.1:
  * Added docs directory and upload_docs command. Fixed bug with
    `__qualname__`, reported by Lucian Petrut (2015/07/28)
- changes from version 4.0.0:
  * Removed the need for 2to3 by dropping the support for Python 2.5.
  * Added a MANIFEST.in file and produced a proper wheel. Improved the
    integration with setuptools so that `python setup.py test` works.
  * Reworked the documentation and introduced `decorator.decorated`.
  * Removed any dependence from `inspect.getargspec`, which is
    deprecated in Python 3.5, as signaled by Ralf Gommers.
  * Fixed `contextmanager` to work with Python 3.5.
  * Copied the `__qualname__` attribute, as requested by Frazer
    McLean.
  * Added a `dispatch_on` facility to implement generic functions.
  (2015/07/24)
* Sun Mar 22 2015 arun@gmx.de
- specfile:
  * changed to setuptools
  * removed python dependency (automated by build process)
  * removed nose
  * README.txt -> REAMDE.rst
- update to version 3.4.2:
  * no changelog available
- changes from version 3.4.1:
  * Ported the repository from GoogleCode to GitHub and added Travis
    CI support. Tests are executed with the new command `python
    test.py -v`.  setuptools is now mandatory in Python 3. The
    suggested installation tool is `pip`, not
    `easy_install`. Supported IronPython and other Python
    implementations without sys._getframe, as requested by Doug Blank
    (2015/03/16)
* Sat Jan 10 2015 arun@gmx.de
- specfile:
  * remove python(abi) requirement
* Fri Jan  9 2015 arun@gmx.de
- specfile: update copyright year
- update to version 3.4.0:
  * Added the ability to use classes and generic callables as callers
    and implemented a signature-preserving contexmanager
    decorator.
  * Fixed a bug with the signature f(**kw) in Python 3 and
  * fixed a couple of doctests broken by Python 3.3, both issues
    pointed out by Dominic Sacré (18/10/2012)
* Thu Nov 22 2012 toddrme2178@gmail.com
- Removed openSUSE 11.4 spec file workarounds
* Thu Jun 14 2012 toddrme2178@gmail.com
- Fix building on openSUSE <= 12.1
- Minor spec file cleanups
* Fri May 25 2012 toddrme2178@gmail.com
- Fix building on openSUSE 11.4
- spec file cleanups
* Wed May 23 2012 highwaystar.ru@gmail.com
- python3-decorator package added
